@@ -17,6 +17,7 @@
 #' @param filename If intermediate is not NULL, save intermediate result in this file
 #' @param intermediate Period for saving intermediate result, NULL for no save
 #' @param previous Previous result to be continued. Can be the filename in which intermediate results are saved.
+#' @param WAIC If TRUE matrix or array are stored to be used with loo or waic. 
 #' @description Run the Metropolis-Hastings algorithm for hatching success.\cr
 #' The number of iterations is n.iter+n.adapt+1 because the initial likelihood is also displayed.\cr
 #' I recommend that thin=1 because the method to estimate SE uses resampling.\cr
@@ -51,11 +52,20 @@
 
 HatchingSuccess.MHmcmc <- function(result=stop("Give a result of HatchingSuccess.fit()"), 
                                     n.iter=10000, 
-                                    parametersMCMC=NULL, n.chains = 1, n.adapt = 0, 
-                                    thin=1, trace=FALSE, traceML=FALSE, batchSize=sqrt(n.iter), 
-                                    adaptive=FALSE, adaptive.lag=500, 
+                                    parametersMCMC=NULL, 
+                                   n.chains = 1, 
+                                   n.adapt = 0, 
+                                    thin=1, 
+                                   trace=FALSE, 
+                                   traceML=FALSE, 
+                                   batchSize=sqrt(n.iter), 
+                                    adaptive=FALSE, 
+                                   adaptive.lag=500, 
                                     adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)},
-                                    intermediate=NULL, filename="intermediate.Rdata", previous=NULL) {
+                                    intermediate=NULL, 
+                                   filename="intermediate.Rdata", 
+                                   previous=NULL, 
+                                   WAIC = FALSE) {
   
   # result=eo_logistic; parametersMCMC=NULL; 
   # n.iter=10000; n.chains = 1;  n.adapt = 0; thin=1; trace=TRUE; batchSize=sqrt(n.iter);intermediate=NULL; filename="intermediate.Rdata"; previous=NULL; adaptive=FALSE; adaptive.lag=500; adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)}
@@ -72,21 +82,32 @@ HatchingSuccess.MHmcmc <- function(result=stop("Give a result of HatchingSuccess
   
   # 29/1/2014; Ajout de result$weight
   # 30/1/2015 Ajout de fixedparameters
-  out <- MHalgoGen(n.iter=n.iter, parameters=parametersMCMC, 
-                   n.chains = n.chains, n.adapt = n.adapt, thin=thin, 
-                   trace=trace, traceML=traceML, 
-                   data=result$data, fixed.parameters=result$fixed.parameters, 
-                   column.Incubation.temperature=result$column.Incubation.temperature,
-                   column.Hatched=result$column.Hatched,
-                   column.NotHatched=result$column.NotHatched,
+  out <- MHalgoGen(n.iter=n.iter                                                        , 
+                   parameters=parametersMCMC                                            , 
+                   n.chains = n.chains                                                  , 
+                   n.adapt = n.adapt                                                    , 
+                   thin=thin                                                            , 
+                   trace=trace                                                          , 
+                   traceML=traceML                                                      , 
+                   data=result$data                                                     , 
+                   fixed.parameters=result$fixed.parameters                             , 
+                   column.Incubation.temperature=result$column.Incubation.temperature   ,
+                   column.Hatched=result$column.Hatched                                 ,
+                   column.NotHatched=result$column.NotHatched                           ,
                    likelihood=getFromNamespace("HatchingSuccess.lnL", ns="embryogrowth"), 
-                   parameters_name = "par", 
-                   adaptive=adaptive, adaptive.lag=adaptive.lag, adaptive.fun=adaptive.fun,
-                   intermediate=intermediate, filename=filename, previous=previous)
+                   parameters_name = "par"                                              , 
+                   adaptive=adaptive                                                    , 
+                   adaptive.lag=adaptive.lag                                            , 
+                   adaptive.fun=adaptive.fun                                            ,
+                   intermediate=intermediate                                            , 
+                   filename=filename                                                    , 
+                   previous=previous                                                    , 
+                   WAIC.out = WAIC                                                      , 
+                   n.datapoints = nrow(result$data)                                     )
   
   fin <- try(summary(out), silent=TRUE)
   
-  if (batchSize>=n.iter/2) {
+  if (batchSize >= n.iter /2 ) {
     print("batchSize cannot be larger than half the number of iterations.")
     rese <- rep(NA, dim(parametersMCMC)[1])
     names(rese) <- rownames(parametersMCMC)
