@@ -82,18 +82,18 @@ HeterogeneityNests <-
            adaptive =TRUE                                                              , 
            return.mcmc=FALSE                                                           , 
            trace = FALSE                                                               , 
-           rules = rbind(data.frame(Name="min", Min=0, Max=2),
-                         data.frame(Name="max", Min=0, Max=20),
+           rules = rbind(data.frame(Name="min", Min=0.01, Max=2),
+                         data.frame(Name="max", Min=0.02, Max=20),
                          data.frame(Name="S", Min=0, Max=10),
                          data.frame(Name="P", Min=0, Max=50),
-                         data.frame(Name="asd", Min=0, Max=2),
-                         data.frame(Name="bsd", Min=0, Max=1))                          ,
+                         data.frame(Name="asd", Min=0.01, Max=2),
+                         data.frame(Name="bsd", Min=0.01, Max=1))                          ,
            fitted.parameters = c('min' = 1,
                       'max' = 3.95,
                       'S' = 0.62,
                       'P' = 5.70,
                       'asd' = 0.014,
-                      'bsd' = 1.19)                                       ,
+                      'bsd' = 1.19)                                                     ,
            fixed.parameters = NULL                                                      ,
            ...                                                                         ) {
     
@@ -123,12 +123,27 @@ HeterogeneityNests <-
     modelH <- function(par, data, fixed.parameters=NULL) {
       par <- c(par, fixed.parameters)
       theoric <- par["min"]+(par["max"]-par["min"])*(1/(1+exp((1/par["S"])*(par["P"]-data[ ,"nb"]))))
-      if (any(abs(par["asd"])*theoric+abs(par["bsd"]) <= 0)) return(1E9)
-      return(sum(-dnorm(x=data[ ,"H"], mean=theoric, sd=abs(par["asd"])*theoric+abs(par["bsd"]), log = TRUE)))
+      sd <- abs(par["asd"])*theoric+abs(par["bsd"])
+      sd <- ifelse(sd == 0, 1E-3, sd)
+      # print(par)
+      # print(theoric)
+      # print(sd)
+      # if (any(abs(par["asd"])*theoric+abs(par["bsd"]) <= 0)) return(1E9)
+      l <- sum(-dnorm(x=data[ ,"H"], mean=theoric, sd=sd, log = TRUE))
+      # print(l)
+      return(l)
     }
     
+    if (!identical(probs, c(0.025, 0.975))) stop("Only 0.025 and 0.975 quantiles are allowed")
+    qnames <- names(quantile(c(0, 0, 0), probs = probs))
+    
     name_nests <- nests$Names
     
+    units <- lapply(nests$Nests, FUN=function(x) unname(x$UnitTime))
+    units <- do.call("c", units)
+    
+    if (any(units != "minutes")) stop("Only time units in minutes is managed at this time.")
+    
     LayingTime <- lapply(nests$Nests, FUN=function(x) unname(as.POSIXct(x$LayingTime)))
     LayingTime <- do.call("c", LayingTime)
     
@@ -143,7 +158,7 @@ HeterogeneityNests <-
     BeginTime$min <- 0
     BeginTime$sec <- 0
     
-    EndTime <- lapply(nests$Nests, FUN=function(x) unname(as.POSIXct(x$LayingTime) + max(x$data[, "Time"])*60))
+    EndTime <- lapply(nests$Nests, FUN=function(x) unname(as.POSIXct(x$LayingTime) + max(x$data[, "Time"])*ifelse(x$UnitTime == "minutes", 60, NA)))
     EndTime <- do.call("c", EndTime)
     
     EndTime <- as.POSIXlt(max(EndTime))
@@ -154,7 +169,7 @@ HeterogeneityNests <-
     EndTime$sec <- 0
     
     
-    dates <- lapply(name_nests, FUN = function(x) as.POSIXct(nests$Nests[[x]]$data[, "Time"] * 60 + LayingTime[x]))
+    dates <- lapply(name_nests, FUN = function(x) as.POSIXct(nests$Nests[[x]]$data[, "Time"] * ifelse(nests$Nests[[x]]$UnitTime == "minutes", 60, NA) + LayingTime[x]))
     dates <- do.call("c", dates)
     
     dates <- sort(unique(dates))
@@ -175,7 +190,7 @@ HeterogeneityNests <-
       
       for (j in name_nests) {
         Eret <- nests$Nests[[j]]$data
-        d <- nests$Nests[[j]]$LayingTime + Eret[, "Time"]*60
+        d <- nests$Nests[[j]]$LayingTime + Eret[, "Time"]*ifelse(nests$Nests[[j]]$UnitTime == "minutes", 60, NA)
         tempsmatrix[which(j == name_nests), match(d, dates)] <- Eret[, "Temperatures C"]
       }
       
@@ -262,7 +277,7 @@ HeterogeneityNests <-
       par(mar=c(4, 4, 1, 1))
       
       param.plot <- modifyList(modifyList(list(x=dta$nb, y=dta$H, xlim=c(2, max(dta$nb)), ylim=c(0, 8),
-                                               pch=19, xlab="Number of overlapping timeseries", ylab = expression("Absolute heterogeneity in "*~degree*C*""),
+                                               pch=19, xlab="Number of overlapping timeseries", ylab = expression("Range of temperatures in "*~degree*C*""),
                                                bty="n", las=1, col=rgb(blue=0.1, green=0.1, red=1, alpha=0.01), xaxt="n"), 
                                           p3p), list(type = "n"))
       
@@ -272,23 +287,23 @@ HeterogeneityNests <-
       points(x=dta$nb, y=dta$H, col=col.absolute.difference.full, pch=pch.absolute.difference.full)
       
       # lines(x, outpar$quantiles["50%", ])
-      if (show.se)
-        polygon(x=c(x, rev(x)), y=c(outpar$quantiles["2.5%", ], rev(outpar$quantiles["97.5%", ])),
-                border = NA, col=rgb(red = 1, green = 0, blue = 0, alpha = 0.2))
       if (show.sd)
-        polygon(x=c(x, rev(x)), y=c(outpar_se$quantiles["2.5%", ], rev(outpar_se$quantiles["97.5%", ])),
+        polygon(x=c(x, rev(x)), y=c(outpar$quantiles[qnames[1], ], rev(outpar$quantiles[qnames[2], ])),
+                border = NA, col=rgb(red = 1, green = 0, blue = 0, alpha = 0.2))
+      if (show.se)
+        polygon(x=c(x, rev(x)), y=c(outpar_se$quantiles[qnames[1], ], rev(outpar_se$quantiles[qnames[2], ])),
                 border = NA, col=rgb(red = 1, green = 0, blue = 0, alpha = 0.6))
       
       segments(x0=1, x1=maxx, y0=summary(mcmc)$quantiles["max", "50%"], y1=summary(mcmc)$quantiles["max", "50%"], col="red", lty=4, lwd=2)
-      segments(x0=1, x1=maxx, y0=summary(mcmc)$quantiles["max", "2.5%"], y1=summary(mcmc)$quantiles["max", "2.5%"], col="red", lty=3, lwd=2)
-      segments(x0=1, x1=maxx, y0=summary(mcmc)$quantiles["max", "97.5%"], y1=summary(mcmc)$quantiles["max", "97.5%"], col="red", lty=3, lwd=2)
+      segments(x0=1, x1=maxx, y0=summary(mcmc)$quantiles["max", qnames[1]], y1=summary(mcmc)$quantiles["max", qnames[1]], col="red", lty=3, lwd=2)
+      segments(x0=1, x1=maxx, y0=summary(mcmc)$quantiles["max", qnames[2]], y1=summary(mcmc)$quantiles["max", qnames[2]], col="red", lty=3, lwd=2)
       cat("Taking into account all data in time series\n")
       cat("-------------------------------------------\n")
       cat(paste("The model converges to an heterogeneity of temperatures of",
                 specify_decimal(unname(summary(mcmc)$quantiles["max", "50%"]), decimals=2),
                 "\u00B0C (95% Credible Interval between",
-                specify_decimal(unname(summary(mcmc)$quantiles["max", "2.5%"]), decimals=2),
-                "and", specify_decimal(unname(summary(mcmc)$quantiles["max", "97.5%"]), decimals=2),
+                specify_decimal(unname(summary(mcmc)$quantiles["max", qnames[1]]), decimals=2),
+                "and", specify_decimal(unname(summary(mcmc)$quantiles["max", qnames[2]]), decimals=2),
                 ") at the scale of the beach.\n"))
       cat(paste("The 95% maximum predicted heterogeneity is",
                 specify_decimal(unname(summary(mcmc)$quantiles["bsd", "50%"])+unname(summary(mcmc)$quantiles["asd", "50%"])*unname(summary(mcmc)$quantiles["max", "50%"]) * 1.96 + unname(summary(mcmc)$quantiles["max", "50%"]), decimals=2),
@@ -398,7 +413,7 @@ HeterogeneityNests <-
         par(mar=c(4, 4, 1, 1))
         
         param.plot <- modifyList(modifyList(list(x=dta$nb, y=dta$H, xlim=c(2, max(dta$nb)), ylim=c(0, 8),
-                                                 pch=19, xlab="Number of overlapping timeseries", ylab = expression("Absolute heterogeneity in "*~degree*C*""),
+                                                 pch=19, xlab="Number of overlapping timeseries", ylab = expression("Range of temperatures in "*~degree*C*""),
                                                  bty="n", las=1, col=rgb(blue=0.1, green=0.1, red=1, alpha=0.01), xaxt="n"), 
                                             p3p), list(type = "n"))
         
@@ -411,26 +426,26 @@ HeterogeneityNests <-
              col=col.absolute.difference.first, pch=pch.absolute.difference.first)
       
       if (show.sd)
-        polygon(x=c(x, rev(x)), y=c(outpar$quantiles["2.5%", ], rev(outpar$quantiles["97.5%", ])),
+        polygon(x=c(x, rev(x)), y=c(outpar$quantiles[qnames[1], ], rev(outpar$quantiles[qnames[2], ])),
                 border = NA, col=rgb(red = 0, green = 0, blue = 1, alpha = 0.2))
       if (show.se)
-        polygon(x=c(x, rev(x)), y=c(outpar_se$quantiles["2.5%", ], rev(outpar_se$quantiles["97.5%", ])),
+        polygon(x=c(x, rev(x)), y=c(outpar_se$quantiles[qnames[1], ], rev(outpar_se$quantiles[qnames[2], ])),
                 border = NA, col=rgb(red = 0, green = 0, blue = 1, alpha = 0.6))
       
       pari <- as.parameters(mcmc, index="median")
       
       segments(x0=2, x1=maxx, y0=unname(summary(mcmc)$quantiles["max", "50%"]), y1=unname(summary(mcmc)$quantiles["max", "50%"]), col="blue", lty=4, lwd=2)
       
-      segments(x0=2, x1=maxx, y0=summary(mcmc)$quantiles["max", "2.5%"], y1=summary(mcmc)$quantiles["max", "2.5%"], col="blue", lty=3, lwd=2)
-      segments(x0=2, x1=maxx, y0=summary(mcmc)$quantiles["max", "97.5%"], y1=summary(mcmc)$quantiles["max", "97.5%"], col="blue", lty=3, lwd=2)
+      segments(x0=2, x1=maxx, y0=summary(mcmc)$quantiles["max", qnames[1]], y1=summary(mcmc)$quantiles["max", qnames[1]], col="blue", lty=3, lwd=2)
+      segments(x0=2, x1=maxx, y0=summary(mcmc)$quantiles["max", qnames[2]], y1=summary(mcmc)$quantiles["max", qnames[2]], col="blue", lty=3, lwd=2)
       
       cat("Taking into account only first half time series\n")
       cat("-----------------------------------------------\n")
       cat(paste("The model converges to an heterogeneity of temperatures of",
                 specify_decimal(unname(summary(mcmc)$quantiles["max", "50%"]), decimals=2),
                 "\u00B0C (95% Credible Interval between",
-                specify_decimal(unname(summary(mcmc)$quantiles["max", "2.5%"]), decimals=2),
-                "and", specify_decimal(unname(summary(mcmc)$quantiles["max", "97.5%"]), decimals=2),
+                specify_decimal(unname(summary(mcmc)$quantiles["max", qnames[1]]), decimals=2),
+                "and", specify_decimal(unname(summary(mcmc)$quantiles["max", qnames[2]]), decimals=2),
                 ") at the scale of the beach.\n"))
       cat(paste("The 95% maximum predicted heterogeneity is",
                 specify_decimal(unname(summary(mcmc)$quantiles["bsd", "50%"])+unname(summary(mcmc)$quantiles["asd", "50%"])*unname(summary(mcmc)$quantiles["max", "50%"]) * 1.96 + unname(summary(mcmc)$quantiles["max", "50%"]), decimals=2),
@@ -438,7 +453,7 @@ HeterogeneityNests <-
     }
     #
     if (show.se & show.sd) {
-      control.legend.total <- modifyList(list(x="bottomright", legend = c("Observations", "95% SD", "95% Bayesian CI model", "Heterogeneity of the beach"),
+      control.legend.total <- modifyList(list(x="bottomright", legend = c("Observations", "95% SE", "95% Bayesian CI model", "Heterogeneity of the beach"),
                                               col=c("lightgrey", "grey", "black", "black"), 
                                               pch=c(pch.absolute.difference.first, 15, NA, NA), lty=c(NA, NA, 1, 3), lwd=c(NA, NA, 3, 1)), 
                                          control.legend.total)
@@ -472,22 +487,22 @@ HeterogeneityNests <-
     
     out <- NULL
     if (show.first.half.incubation & show.full.incubation)
-      out <- c(lower.max.half=unname(summary(mcmc)$quantiles["max", "2.5%"]), 
+      out <- c(lower.max.half=unname(summary(mcmc)$quantiles["max", qnames[1]]), 
                median.max.half=unname(summary(mcmc)$quantiles["max", "50%"]), 
-               upper.max.half=unname(summary(mcmc)$quantiles["max", "97.5%"]), 
-               lower.max=unname(summary(mcmc_tot)$quantiles["max", "2.5%"]), 
+               upper.max.half=unname(summary(mcmc)$quantiles["max", qnames[2]]), 
+               lower.max=unname(summary(mcmc_tot)$quantiles["max", qnames[1]]), 
                median.max=unname(summary(mcmc_tot)$quantiles["max", "50%"]), 
-               upper.max=unname(summary(mcmc_tot)$quantiles["max", "97.5%"]))
+               upper.max=unname(summary(mcmc_tot)$quantiles["max", qnames[2]]))
     
     if (show.first.half.incubation & !show.full.incubation)
-      out <- c(lower.max.half=unname(summary(mcmc)$quantiles["max", "2.5%"]), 
+      out <- c(lower.max.half=unname(summary(mcmc)$quantiles["max", qnames[1]]), 
                median.max.half=unname(summary(mcmc)$quantiles["max", "50%"]), 
-               upper.max.half=unname(summary(mcmc)$quantiles["max", "97.5%"]))
+               upper.max.half=unname(summary(mcmc)$quantiles["max", qnames[2]]))
     
     if (!show.first.half.incubation & show.full.incubation)
-      out <- c(lower.max=unname(summary(mcmc_tot)$quantiles["max", "2.5%"]), 
+      out <- c(lower.max=unname(summary(mcmc_tot)$quantiles["max", qnames[1]]), 
                median.max=unname(summary(mcmc_tot)$quantiles["max", "50%"]), 
-               upper.max=unname(summary(mcmc_tot)$quantiles["max", "97.5%"]))
+               upper.max=unname(summary(mcmc_tot)$quantiles["max", qnames[2]]))
     
     if (return.mcmc) {
       if (show.first.half.incubation & show.full.incubation)
