@@ -51,13 +51,20 @@
 #' }
 #' @export
 
-P_TRT <- function(x=NULL, resultmcmc=NULL, fixed.parameters=NULL, 
-                  chain=1, equation=NULL, l=0.05, 
-                  replicate.CI=NULL, temperatures=NULL, durations=NULL,
-                  SD.temperatures= NULL, SD.durations=NULL,
-                  probs=c(0.025, 0.5, 0.975), 
-                  warn=TRUE) {
-  
+P_TRT <- function(x=NULL                     , 
+                  resultmcmc=NULL            , 
+                  fixed.parameters=NULL      , 
+                  chain=1                    , 
+                  equation=NULL              , 
+                  l=0.05                     , 
+                  replicate.CI=NULL          , 
+                  temperatures=NULL          , 
+                  durations=NULL             ,
+                  SD.temperatures= NULL      , 
+                  SD.durations=NULL          ,
+                  probs=c(0.025, 0.5, 0.975) , 
+                  warn=TRUE                  ) {
+   
   # x=NULL; resultmcmc=NULL; fixed.parameters=NULL; chain=1; equation=NULL; l=0.05; replicate.CI=NULL; temperatures=NULL; durations=NULL; SD.temperatures= NULL; SD.durations=NULL; probs=c(0.025, 0.5, 0.975); warn=TRUE
   
   modelTSD <- getFromNamespace(".modelTSD", ns="embryogrowth")
@@ -381,7 +388,7 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, fixed.parameters=NULL,
     srT <- apply(X = par, MARGIN=1, function(xpar) {
       
       if (all(is.finite(c(temperatures, SD)))) {
-        p <- modelTSD(xpar, rnorm(length(temperatures), temperatures, SD), equation)
+        p <- modelTSD(par=xpar, temperatures=rnorm(length(temperatures), temperatures, SD), equation=equation)
         if (any(is.na(p))) {
           warning(paste0("Error for this set of parameters: ", paste0(as.character(xpar), collapse="; "), "; temperatures=", paste0(as.character(temperatures), collapse="; ")))
         }
