@@ -214,7 +214,8 @@ plotR <-
                                                                     ParTofn = "parms", 
                                                                     fn=SSM, 
                                                                     set.par=set.par, 
-                                                                    T=temp)
+                                                                    T=temp, 
+                                                                    regularThin = ifelse(replicate.CI > nrow(resultmcmc$resultMCMC[[chain]]), FALSE, TRUE))
     }
     
     # j'ai un hessian qui est fourni
