@@ -6,13 +6,14 @@
 #' @param females A vector with female numbers
 #' @param N A vector with total numbers
 #' @param temperatures The constant incubation temperatures used to fit sex ratio
+#' @param sd The SD for each temperature in temperatures
 #' @param durations The duration of incubation or TSP used to fit sex ratio
 #' @param df A dataframe with at least two columns named males, females or N and temperatures, Incubation.temperature or durations column
 #' @param l Sex ratio limits to define TRT are l and 1-l (see Girondot, 1999)
 #' @param parameters.initial Initial values for P, S or K search as a vector, ex. c(P=29, S=-0.3)
 #' @param fixed.parameters Parameters that will not be changed
 #' @param males.freq If TRUE data are shown as males frequency
-#' @param equation Can be "logistic", "Hill", "A-logistic", "Hulin", "Double-A-logistic", "flexit", "flexit*", "flexit**", "GSD", "logit", "probit"
+#' @param equation Can be "logistic", "Hill", "A-logistic", "Hulin", "Double-A-logistic", "flexit", "flexit*", "flexit**", "GSD", "logit", "probit", "stairs"
 #' @param replicate.CI Number of replicates to estimate confidence intervals
 #' @param replicate.NullDeviance Number of replicates to estimate null distribution of deviance
 #' @param SE If FALSE, does not estimate SE of parameters. Can be use when something wrong happens.
@@ -123,7 +124,7 @@
 #'                
 #' ##############
 #' eo <- subset(DatabaseTSD, Species=="Emys orbicularis", c("Males", "Females", 
-#'                                        "Incubation.temperature"))
+#'                                        "Incubation.temperature.set"))
 #'                                        
 #' eo_Hill <- with(eo, tsd(males=Males, females=Females, 
 #'                                        temperatures=Incubation.temperature.set,
@@ -262,8 +263,9 @@
 #' out_mcmc <- tsd_MHmcmc(result=model_TSDII, n.iter=10000, parametersMCMC=priors)
 #' plot(model_TSDII, resultmcmc=out_mcmc, lab.TRT = "TRT l = 5 %")
 #' predict(model_TSDII, temperatures=25:35)
-#' 
-#' # Podocnemis expansa
+#' ######################
+#' # Podocnemis expansa #
+#' ######################
 #' Podocnemis_expansa <- subset(DatabaseTSD, !is.na(Sexed) & (Sexed != 0) & 
 #'                        Species=="Podocnemis expansa")
 #' Podocnemis_expansa_Valenzuela_2001 <- subset(Podocnemis_expansa, 
@@ -369,6 +371,8 @@
 #' temperatures[which.min(abs(SR - 0.5))]
 #' # The TRT: SH + SL
 #' temperatures[which.min(abs(SR - l))] - temperatures[which.min(abs(SR - (1 -l)))]
+#' 
+#'                          
 #' }
 #' @export
 
@@ -378,6 +382,7 @@ tsd <- function(df=NULL
                 females=NULL                                                    , 
                 N=NULL                                                          , 
                 temperatures=NULL                                               , 
+                sd=NULL                                                         ,
                 durations=NULL                                                  ,
                 l=0.05                                                          , 
                 parameters.initial=c(P=30, S=-2, K=0, K1=1, K2=0, 
@@ -468,6 +473,12 @@ tsd <- function(df=NULL
     stop("A temperature or duration must be provided for each experiment")
   }
   
+  if (!is.null(sd)) {
+    if (length(temperatures) != length(sd)) {
+      stop("A sd value must must be provided for each temperature")
+    }
+  }
+  
   if (all(males * females == 0)) {
     warning("At least one incubation temperature should produce mixed sex ratio. Use MCMC rather.")
   }
@@ -501,27 +512,27 @@ tsd <- function(df=NULL
     ppi <- c(parameters.initial, fixed.parameters)
     
     if (equation != "stairs") {
-    if (is.na(ppi["P_low"])) {
-      if (is.na(ppi["P"])) {
-        if ((equation!="probit") & (equation!="logit")) {
-          ppi["P"] <- unname(temperatures[which.min(abs((males/(males+females))-0.5))][1])
-        } else {
-          ppi["P"] <- 0
+      if (is.na(ppi["P_low"])) {
+        if (is.na(ppi["P"])) {
+          if ((equation!="probit") & (equation!="logit")) {
+            ppi["P"] <- unname(temperatures[which.min(abs((males/(males+females))-0.5))][1])
+          } else {
+            ppi["P"] <- 0
+          }
         }
       }
     }
-    }
     
     if (equation != "stairs") {
-    if ((is.na(ppi["S"])) & (is.na(ppi["SL"])) & (is.na(ppi["SH"]))) {
-      if ((equation!="probit")) {
-        pente <- lm(males/(males+females) ~ temperatures, weights=males+females)
-        ppi["S"] <- pente$coefficients["temperatures"]
-        if ((equation != "flexit") & (equation != "flexit*") & (equation != "flexit**")) ppi["S"] <- 1/(4*ppi["S"])
-      } else {
-        ppi["S"] <- 0
+      if ((is.na(ppi["S"])) & (is.na(ppi["SL"])) & (is.na(ppi["SH"]))) {
+        if ((equation!="probit")) {
+          pente <- lm(males/(males+females) ~ temperatures, weights=males+females)
+          ppi["S"] <- pente$coefficients["temperatures"]
+          if ((equation != "flexit") & (equation != "flexit*") & (equation != "flexit**")) ppi["S"] <- 1/(4*ppi["S"])
+        } else {
+          ppi["S"] <- 0
+        }
       }
-    }
     } 
     
     # if (IP) ppi["S"] <- abs(ppi["S"])
@@ -587,6 +598,7 @@ tsd <- function(df=NULL
       # getFromNamespace(".modelTSD", ns="embryogrowth")(par=c(ppi, fixed.parameters), temperatures=temperatures, equation=equation)
       result  <- try(optim(ppi, getFromNamespace(".tsd_fit", ns="embryogrowth"), 
                            fixed.parameters=fixed.parameters, males=males, N=N, temperatures=temperatures, 
+                           sd=sd, 
                            equation=equation, method=method, hessian=FALSE, control = control),  silent=TRUE)
       if (inherits(result, "try-error")) {
         stop("Try using method='Nelder-Mead' or use MCMC ! Contact Marc Girondot if you need some advices.")
@@ -604,6 +616,7 @@ tsd <- function(df=NULL
     
     result_hessian  <- try(optim(result$par, getFromNamespace(".tsd_fit", ns="embryogrowth"), 
                                  fixed.parameters=fixed.parameters, males=males, N=N, temperatures=temperatures, 
+                                 sd=sd, 
                                  equation=equation, method=method, hessian=TRUE, control = control), silent=TRUE)
     
     
@@ -650,6 +663,7 @@ tsd <- function(df=NULL
   result$females <- females
   result$N <- N
   result$temperatures <- temperatures
+  result$sd <- sd
   result$males.freq <- males.freq
   result$fixed.parameters <- fixed.parameters
   result$type <- ifelse(IP, "duration", "temperature")
@@ -693,17 +707,18 @@ tsd <- function(df=NULL
       result$SE <- NULL
       replicate.CI = 0
     }
-      o <- P_TRT(x=result, l=l, 
-                 replicate.CI = replicate.CI, 
-                 probs = c((1-range.CI)/2, 0.5, 1-(1-range.CI)/2))
-      
-      
-      result$P_TRT <- o$P_TRT_quantiles
+    o <- P_TRT(x=result, l=l, 
+               replicate.CI = replicate.CI, 
+               probs = c((1-range.CI)/2, 0.5, 1-(1-range.CI)/2))
+    
+    
+    result$P_TRT <- o$P_TRT_quantiles
     
   }
   
-  probtheor <- getFromNamespace(x=".modelTSD", ns="embryogrowth")(c(result$par, result$fixed.parameters), 
-                                                                  result$temperatures, 
+  probtheor <- getFromNamespace(x=".modelTSD", ns="embryogrowth")(par=c(result$par, result$fixed.parameters), 
+                                                                  temperatures=result$temperatures, 
+                                                                  sd=result$sd, 
                                                                   equation=equation)
   result$predictMaleFrequency <- probtheor
   
@@ -715,6 +730,7 @@ tsd <- function(df=NULL
       result_dev  <- optim(par=result$par, fn=getFromNamespace(".tsd_fit", ns="embryogrowth"), 
                            fixed.parameters=result$fixed.parameters, males=m, N=result$N, 
                            temperatures=result$temperatures, 
+                           sd=result$sd, 
                            equation=result$equation, method=method, 
                            hessian=FALSE, control = control)
       deviance_dev <- -2*(-result$value - sum(dbinom(x = m, size=N, 
@@ -741,44 +757,44 @@ tsd <- function(df=NULL
       }
       
     } else {
-    # SI je n'ai qu'un PT c'est que c'est un profile TSDIA ou IB
-    if (any(colnames(o$P_TRT_quantiles)=="PT")) {
-      if (!is.null(replicate.CI) & (replicate.CI != 0)) {
-        print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"]))))
-        print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"]))))
-        print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"]))))
-        print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"]))))
-        if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
+      # SI je n'ai qu'un PT c'est que c'est un profile TSDIA ou IB
+      if (any(colnames(o$P_TRT_quantiles)=="PT")) {
+        if (!is.null(replicate.CI) & (replicate.CI != 0)) {
+          print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT"], o$P_TRT_quantiles[3, "PT"]))))
+          print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT"], o$P_TRT_quantiles[3, "TRT"]))))
+          print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT"], o$P_TRT_quantiles[3, "lower.limit.TRT"]))))
+          print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT"], o$P_TRT_quantiles[3, "higher.limit.TRT"]))))
+          if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
+        } else {
+          print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"])))
+          print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"])))
+          print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"])))
+          print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"])))
+          if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
+        }
       } else {
-        print(paste0("The pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT"])))
-        print(paste0("The transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT"])))
-        print(paste0("The lower limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT"])))
-        print(paste0("The upper limit of transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT"])))
-        if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
+        if (!is.null(replicate.CI) & (replicate.CI != 0)) {
+          print(paste0("The lower pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT_low"], o$P_TRT_quantiles[3, "PT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT_low"], o$P_TRT_quantiles[3, "PT_low"]))))
+          print(paste0("The lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT_low"], o$P_TRT_quantiles[3, "TRT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT_low"], o$P_TRT_quantiles[3, "TRT_low"]))))
+          print(paste0("The lower limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT_low"], o$P_TRT_quantiles[3, "lower.limit.TRT_low"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT_low"], o$P_TRT_quantiles[3, "lower.limit.TRT_low"]))))
+          print(paste0("The upper limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT_low"], o$P_TRT_quantiles[3, "higher.limit.TRT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT_low"], o$P_TRT_quantiles[3, "higher.limit.TRT_low"]))))
+          print(paste0("The upper pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT_high"], o$P_TRT_quantiles[3, "PT_high"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT_high"], o$P_TRT_quantiles[3, "PT_high"]))))
+          print(paste0("The upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT_high"], o$P_TRT_quantiles[3, "TRT_high"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT_high"], o$P_TRT_quantiles[3, "TRT_high"]))))
+          print(paste0("The lower limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT_high"], o$P_TRT_quantiles[3, "lower.limit.TRT_high"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT_high"], o$P_TRT_quantiles[3, "lower.limit.TRT_high"]))))
+          print(paste0("The upper limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT_high"], o$P_TRT_quantiles[3, "higher.limit.TRT_high"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT_high"], o$P_TRT_quantiles[3, "higher.limit.TRT_high"]))))
+          if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
+        } else {
+          print(paste0("The lower pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_low"])))
+          print(paste0("The lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_low"])))
+          print(paste0("The lower limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_low"])))
+          print(paste0("The upper limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_low"])))
+          print(paste0("The upper pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_high"])))
+          print(paste0("The upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_high"])))
+          print(paste0("The lower limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_high"])))
+          print(paste0("The upper limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_high"])))
+          if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
+        }
       }
-    } else {
-      if (!is.null(replicate.CI) & (replicate.CI != 0)) {
-        print(paste0("The lower pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT_low"], o$P_TRT_quantiles[3, "PT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT_low"], o$P_TRT_quantiles[3, "PT_low"]))))
-        print(paste0("The lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT_low"], o$P_TRT_quantiles[3, "TRT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT_low"], o$P_TRT_quantiles[3, "TRT_low"]))))
-        print(paste0("The lower limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT_low"], o$P_TRT_quantiles[3, "lower.limit.TRT_low"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT_low"], o$P_TRT_quantiles[3, "lower.limit.TRT_low"]))))
-        print(paste0("The upper limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_low"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT_low"], o$P_TRT_quantiles[3, "higher.limit.TRT_low"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT_low"], o$P_TRT_quantiles[3, "higher.limit.TRT_low"]))))
-        print(paste0("The upper pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f", min(o$P_TRT_quantiles[1, "PT_high"], o$P_TRT_quantiles[3, "PT_high"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "PT_high"], o$P_TRT_quantiles[3, "PT_high"]))))
-        print(paste0("The upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "TRT_high"], o$P_TRT_quantiles[3, "TRT_high"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "TRT_high"], o$P_TRT_quantiles[3, "TRT_high"]))))
-        print(paste0("The lower limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "lower.limit.TRT_high"], o$P_TRT_quantiles[3, "lower.limit.TRT_high"])), ";", sprintf("%.3f", max(o$P_TRT_quantiles[1, "lower.limit.TRT_high"], o$P_TRT_quantiles[3, "lower.limit.TRT_high"]))))
-        print(paste0("The upper limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_high"]), " CI", as.character(range.CI*100), "% ", sprintf("%.3f",min(o$P_TRT_quantiles[1, "higher.limit.TRT_high"], o$P_TRT_quantiles[3, "higher.limit.TRT_high"])), ";", sprintf("%.3f",max(o$P_TRT_quantiles[1, "higher.limit.TRT_high"], o$P_TRT_quantiles[3, "higher.limit.TRT_high"]))))
-        if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
-      } else {
-        print(paste0("The lower pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_low"])))
-        print(paste0("The lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_low"])))
-        print(paste0("The lower limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_low"])))
-        print(paste0("The upper limit of lower transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_low"])))
-        print(paste0("The upper pivotal ", result$type, " is ", sprintf("%.3f",o$P_TRT_quantiles[2, "PT_high"])))
-        print(paste0("The upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "TRT_high"])))
-        print(paste0("The lower limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "lower.limit.TRT_high"])))
-        print(paste0("The upper limit of upper transitional range of ", result$type, "s is ", sprintf("%.3f",o$P_TRT_quantiles[2, "higher.limit.TRT_high"])))
-        if (!is.na(result$par["S"])) print(paste0("The S parameter value is ", sprintf("%.3f",result$par["S"])))
-      }
-    }
     }
   }
   
