@@ -71,6 +71,8 @@ tsd_MHmcmc_p<-function(result=stop("An output from tsd() must be provided"),
   equation <- result$equation
   
   dpriors_norm <- NULL
+  dpriors_norm <- rbind(dpriors_norm, 
+                        data.frame(Density="dnorm", Prior1=unname(ifelse(is.na(par["SD"]), 0, par["SD"])), Prior2=1, SDProp=0.5, Min=min(c(-2, ifelse(is.na(par["SD"]), 0, par["SD"])-2)), Max=max(c(2, ifelse(is.na(par["SD"]), 0, par["SD"])+2)), Init=unname(ifelse(is.na(par["SD"]), 0,par["SD"])), row.names = "SD"))
   dpriors_norm <- rbind(dpriors_norm, 
                         data.frame(Density="dnorm", Prior1=par["P"], Prior2=sdpx, SDProp=sdpx, Min=min(c(minx, par["P"]-5)), Max=max(c(maxx, par["P"]+5)), Init=par["P"], row.names ="P"))
   dpriors_norm <- rbind(dpriors_norm, 
@@ -121,6 +123,8 @@ tsd_MHmcmc_p<-function(result=stop("An output from tsd() must be provided"),
                         data.frame(Density="dnorm", Prior1=ifelse(is.na(par["TRTH"]), 1, par["TRTH"]), Prior2=sdpx, SDProp=sdpx, Min=min(c(minx-10, par["TRTH"]-5)), Max=max(c(maxx+10, par["TRTH"]+5)), Init=par["TRTH"], row.names ="TRTH"))
   dpriors_norm <- rbind(dpriors_norm, 
                         data.frame(Density="dnorm", Prior1=ifelse(is.na(par["SRTRT"]), 0, par["SRTRT"]), Prior2=2, SDProp=1, Min=min(c(-10, par["SRTRT"]-5)), Max=max(c(10, par["SRTRT"]+5)), Init=par["SRTRT"], row.names ="SRTRT"))
+  dpriors_norm <- rbind(dpriors_norm, 
+                        data.frame(Density="dnorm", Prior1=ifelse(is.na(par["SD"]), 0, par["SD"]), Prior2=2, SDProp=1, Min=min(c(-2, par["SD"]-3)), Max=max(c(3, par["SD"]+3)), Init=par["SD"], row.names ="SD"))
   
   dpriors_unif <- dpriors_norm
   dpriors_unif[, "Density"] <- "dunif"
