@@ -1,8 +1,8 @@
-.tsd_fit <- function(par, fixed.parameters=NULL, males, N, temperatures, equation) {
+.tsd_fit <- function(par, fixed.parameters=NULL, males, N, temperatures, sd, equation) {
   
   #  print(dput(par))
   par <- c(par, fixed.parameters)
-  p <- getFromNamespace(".modelTSD", ns="embryogrowth")(par, temperatures, equation)
+  p <- getFromNamespace(".modelTSD", ns="embryogrowth")(par, temperatures, sd, equation)
   p <- ifelse(p<=1E-9, 1E-9, p)
   p <- ifelse(p>=1-1E-9, 1-1E-9, p)
   
